<?php

namespace EventPortal\Http\Controllers\Admin\EventVenue;

use EventPortal\Concerns\EventRequiresReApproval;
use EventPortal\Domain\ActionList\ActionList;
use EventPortal\Domain\Event\Models\Event;
use EventPortal\Domain\EventVenue\Actions\AssociateToEvent;
use EventPortal\Http\Controllers\Controller;
use Illuminate\Http\RedirectResponse;
use Illuminate\Http\Request;

class AssociateToEventController extends Controller
{
    use EventRequiresReApproval;

    public function __construct()
    {
        $this->middleware('check-permission:event-venue.add');
    }

    public function __invoke(Request $request, Event $event, AssociateToEvent $action): RedirectResponse
    {
        $action->execute($event, $request->all());

        if ($this->doesEventRequireReApproval($event)) {
            $event->updateApprovalStatusToRequireResubmission();
        }

        ActionList::make('event')->state($event->state)->type($event->type)->complete('venue');

        return redirect()->route('admin.event.venue.index', $event);
    }
}
